<template>
    <div>
        <el-dialog :title="title" :visible.sync="taskCreateDialog" :modal-append-to-body="false" :close-on-click-modal="false" width="70%">
            <el-tabs type="border-card" class="active" v-model="activeName">
                <el-tab-pane label="作业基本信息" name="taskBasic" v-if="ifHotFireBasic">
                    <task-basic ref="taskBasic" :title="title" @changeCardToSafetyActionEdit="changeToSecond" @changeToConstructionConfirm="constructionConfirm"></task-basic>
                </el-tab-pane>
                <el-tab-pane label="安全措施" name="safetyAction" v-if="ifSafetyAction">
                    <safety-action ref="safetyAction" :basicInformation="basicForm" :title="title" @changeToCardFile="changeToThird" @changeToConstructionConfirm="constructionConfirm" @confirmConstruction="confirmConstruction"></safety-action>
                </el-tab-pane>
                <el-tab-pane label="安全交底和风险告知确认卡" name="safetyAndRiskConfirm" v-if="ifSafetyAndRisk">
                    <safety-and-risk-confirm ref="safetyAndRiskConfirm" :title="title" :basicInformation="basicForm" @changeToCardFile="changeToThird" @changeToConstructionConfirm="constructionConfirm"></safety-and-risk-confirm>
                </el-tab-pane>
                <el-tab-pane label="设备" name="equipment" v-if="ifSafetyAction">
                    <equipment ref="equipment" :basicInformation="basicForm" :title="title" @changeToCardFile="changeToThird" @changeToConstructionConfirm="constructionConfirm" @confirmConstruction="confirmConstruction"></equipment>
                </el-tab-pane>
                <el-tab-pane label="作业人" name="fireMan" v-if="ifFireMan">
                    <fire-man ref="fireMan" :basicInformation="basicForm" :title="title" @confirmConstruction="confirmConstruction"></fire-man>
                </el-tab-pane>
                <el-tab-pane label="文件" name="fileAndEquipment" v-if="ifFile">
                    <file ref="fileAndEquipment" :basicInformation="basicForm" :title="title" @confirm="confirmFile" @changeToConstructionConfirm="constructionConfirm"></file>
                </el-tab-pane>
                <el-tab-pane label="文件" name="constructionFile" v-if="ifConstructionFile">
                    <construction-file ref="constructionFile" :basicInformation="basicForm" :title="title" @changeToConstructionConfirm="constructionConfirm" @confirmConstruction="confirmConstruction"></construction-file>
                </el-tab-pane>
                <el-tab-pane label="文件" name="allFile" v-if="ifAllFile">
                    <all-file ref="allFile" :basicInformation="basicForm" :title="title" @changeToConstructionConfirm="constructionConfirm" @confirmConstruction="confirmConstruction"></all-file>
                </el-tab-pane>
            </el-tabs>
            <div align="center" style="padding-top: 20px" v-if="title === '动火部位审批' || title === '相关部门审批' || title=== '安全部门审批'">
                <el-button type="danger" @click="refuse">拒绝</el-button>
                <el-button type="primary" @click="agree">同意</el-button>
            </div>
            <el-dialog :visible.sync="supervisorAndAnalystAgree" :modal-append-to-body="false" :close-on-click-modal="false" width="25%">
                <div align="center">
                    <span>监火人：</span>
                    <el-input v-model="basicForm.analyst" style="width:200px">
                    </el-input>
                </div>
                <div align="center" style="padding-top: 20px">
                    <span>分析人：</span>
                    <el-input v-model="basicForm.approversupervisor" style="width:200px">
                    </el-input>
                    <div  align="center" style="padding-top: 20px">
                        <el-button type="primary" @click="submitAgreeTaskByFireDepartment()">确定</el-button>
                    </div>
                </div>
            </el-dialog>
            <el-dialog title="驳回意见" :visible.sync="supervisorAndAnalystRefuse" :modal-append-to-body="false" :close-on-click-modal="false" width="40%">
                <div align="center">
                    <el-input type="textarea" :row="2" v-model="basicForm.applyunitopinion" style="width:400px">
                    </el-input>
                </div>
                <div  align="center" style="padding-top: 20px">
                    <el-button type="primary" @click="submitRefuseTaskByFireDepartment()">确定</el-button>
                </div>
            </el-dialog>
            <el-dialog title="驳回意见" :visible.sync="relevantRefuse" :modal-append-to-body="false" :close-on-click-modal="false" width="40%">
                <div align="center">
                    <el-input type="textarea" :row="2" v-model="basicForm.relevantopinion" style="width:400px">
                    </el-input>
                </div>
                <div  align="center" style="padding-top: 20px">
                    <el-button type="primary" @click="submitRefuseTaskByFireDepartment()">确定</el-button>
                </div>
            </el-dialog>
            <el-dialog title="驳回意见" :visible.sync="securityRefuse" :modal-append-to-body="false" :close-on-click-modal="false" width="40%">
                <div align="center">
                    <el-input type="textarea" :row="2" v-model="basicForm.securityopinion" style="width:400px">
                    </el-input>
                </div>
                <div  align="center" style="padding-top: 20px">
                    <el-button type="primary" @click="submitRefuseTaskByFireDepartment()">确定</el-button>
                </div>
            </el-dialog>
        </el-dialog>
    </div>
</template>

<script>
import allFile from './file/allFire'
import constructionFile from './file/constructionFile'
import file from './file/index'
import fireMan from './fireMan/index'
import equipment from './equipment/index'
import safetyAndRiskConfirm from './safetyAndRiskConfirm/index'
import safetyAction from './safetyAction/index'
import taskBasic from './taskBasic/index'
import {
    addTaskSecond,
    involveReview, partReview,
    securityReview,
    submitConstruction,
    updateTaskSecond
} from '../../../../../api/task'
import { parseError } from '../../../../../utils/messageDialog'
export default {
    name: 'taskCreate',
    data(){
        return{
            taskCreateDialog:false,
            activeName:'taskBasic',
            title:'',
            basicForm:{},
            constructionForm:{},
            ifHotFireBasic:false,
            ifSafetyAction:false,
            ifSafetyAndRisk:false,
            ifFireMan:false,
            ifFile:false,
            ifConstructionFile:false,
            ifAllFile:false,
            supervisorAndAnalystAgree:false,
            supervisorAndAnalystRefuse:false,
            relevantRefuse:false,
            securityRefuse:false,
        }
    },
    components:{
        taskBasic,
        safetyAction,
        safetyAndRiskConfirm,
        equipment,
        fireMan,
        file,
        constructionFile,
        allFile
    },
    methods:{
        openTaskInfo(value,title){
            this.title = title
            this.taskCreateDialog = true
            this.activeName = 'taskBasic'
            if(title === '新增'){
                this.ifHotFireBasic = true
                this.ifSafetyAction = false
                this.ifSafetyAndRisk = false
                this.ifFireMan = false
                this.ifFile = false
                this.ifAllFile = false
                this.ifConstructionFile = false
                setTimeout(()=>{
                    this.$refs.taskBasic.type = 1
                    this.$refs.taskBasic.activeNames = ['0']
                    this.$refs.taskBasic.taskBasicForm = {
                        unit:sessionStorage.getItem('company'),
                        department:sessionStorage.getItem('department'),
                        applicant:sessionStorage.getItem('realname'),
                        applyunitname: "",
                        applyunitopinion: "",
                        applyunittime: "",
                        approverprofession: "",
                        approversupervisor: "",
                        area: "",
                        code: "",
                        completedconfirm: "",
                        completedname: "",
                        completedtime: "",
                        constructionname: "",
                        constructionopinion: "",
                        constructiontime: "",
                        constructionunit: "",
                        createdat: "",
                        createdby: "",
                        director: "",
                        endtime: "",
                        enterprisename: "",
                        enterpriseopinion: "",
                        enterprisetime: "",
                        flag: 0,
                        hazard: [],
                        id: 0,
                        isdel: 0,
                        isholiday: null,
                        level:'',
                        modifiedat: "",
                        modifiedby: "",
                        othertask: "",
                        partdirector: "",
                        profession: "",
                        relevantname: "",
                        relevantopinion: "",
                        relevanttime: "",
                        resources: [
                        ],
                        securityname: "",
                        securityopinion: "",
                        securitytime: "",
                        securitydep: "",
                        shiftleadername: "",
                        shiftleaderopinion: "",
                        shiftleadertime: "",
                        starttime: "",
                        status: 0,
                        supervisor: "",
                        taskAnalyses: [
                        ],
                        taskEquipments: [
                        ],
                        taskRisk: {
                            confirmat: "",
                            content: "",
                            createdat: "",
                            createdby: "",
                            director: "",
                            emergency: "",
                            environment: "",
                            flag: 0,
                            id: 0,
                            modifiedat: "",
                            modifiedby: "",
                            other: "",
                            preventive: "",
                            taskcode: "",
                            taskdirector: ""
                        },
                        taskSecurities: [
                        ],
                        taskWorkers: [
                        ],
                        subTaskInfos:[],
                        type:'',
                        category:'',
                        firelevel:'',
                        checked:'',
                        spacecategory:'',
                        spacename:'',
                        spacemedium:'',
                        acibase:'',
                        hoistinglevel:'',
                        hoistingweight:'',
                        soildepth:'',
                        soilarea:'',
                        soilfile:[],
                        breakreason:'',
                        breakfile:[],
                        workheight:'',
                        heightlevel:'',
                        electricityarea:'',
                        voltage:'',
                        power:'',
                        pipename:'',
                        pipemedium:'',
                        pipetemperature:'',
                        pipepressure:'',
                        blindboardmaterial:'',
                        blindboardspecification:'',
                        blindboardnumber:'',
                        commander:'',
                        blindboardlocation:[],
                        firetype:'',
                        description:'',
                        isanalysis:'',
                        analysisarea:'',
                        analysismedium:''
                    }
                    this.$refs.taskBasic.ifIncludeArea = null
                    this.$refs.taskBasic.ifHoisting = null
                    this.$refs.taskBasic.ifBuliding = null
                    this.$refs.taskBasic.ifIncludeRoad = null
                    this.$refs.taskBasic.ifIncludeHigh = null
                    this.$refs.taskBasic.ifIncludeElectricity = null
                    this.$refs.taskBasic.ifIncludePump = null
                    this.$refs.taskBasic.ifIncludeFire = null
                    this.$refs.taskBasic.resetFormRules()
                })
            }
            else if(title === '编辑'){
                this.ifSafetyAction = false
                this.ifSafetyAndRisk = false
                this.ifFireMan = false
                this.ifFile = false
                this.ifConstructionFile = false
                this.ifAllFile = false
                this.ifHotFireBasic = true
                this.basicForm = JSON.parse(JSON.stringify(value))
                setTimeout(()=>{
                    this.$refs.taskBasic.type = 2
                    this.$refs.taskBasic.resetFormRules()
                    this.$refs.taskBasic.taskBasicForm = JSON.parse(JSON.stringify(value))
                    this.$refs.taskBasic.taskBasicForm.hazard = this.$refs.taskBasic.taskBasicForm.hazard.split('、')
                    let form = JSON.parse(JSON.stringify(value)).subTaskInfos
                    this.$refs.taskBasic.taskBasicForm.type = ''
                    this.$refs.taskBasic.taskBasicForm.category = ''
                    this.$refs.taskBasic.taskBasicForm.firelevel = ''
                    this.$refs.taskBasic.taskBasicForm.checked = ''
                    this.$refs.taskBasic.taskBasicForm.spacecategory = ''
                    this.$refs.taskBasic.taskBasicForm.spacename = ''
                    this.$refs.taskBasic.taskBasicForm.spacemedium = ''
                    this.$refs.taskBasic.taskBasicForm.acibase = ''
                    this.$refs.taskBasic.taskBasicForm.hoistinglevel = ''
                    this.$refs.taskBasic.taskBasicForm.hoistingweight = ''
                    this.$refs.taskBasic.taskBasicForm.soildepth = ''
                    this.$refs.taskBasic.taskBasicForm.soilarea = ''
                    this.$refs.taskBasic.taskBasicForm.soilfile = []
                    this.$refs.taskBasic.taskBasicForm.breakreason = ''
                    this.$refs.taskBasic.taskBasicForm.breakfile = []
                    this.$refs.taskBasic.taskBasicForm.workheight = ''
                    this.$refs.taskBasic.taskBasicForm.heightlevel = ''
                    this.$refs.taskBasic.taskBasicForm.electricityarea = ''
                    this.$refs.taskBasic.taskBasicForm.voltage = ''
                    this.$refs.taskBasic.taskBasicForm.power = ''
                    this.$refs.taskBasic.taskBasicForm.pipename = ''
                    this.$refs.taskBasic.taskBasicForm.pipemedium = ''
                    this.$refs.taskBasic.taskBasicForm.pipetemperature = ''
                    this.$refs.taskBasic.taskBasicForm.pipepressure = ''
                    this.$refs.taskBasic.taskBasicForm.blindboardmaterial = ''
                    this.$refs.taskBasic.taskBasicForm.blindboardspecification = ''
                    this.$refs.taskBasic.taskBasicForm.blindboardnumber = ''
                    this.$refs.taskBasic.taskBasicForm.commander = ''
                    this.$refs.taskBasic.taskBasicForm.blindboardlocation = []
                    this.$refs.taskBasic.taskBasicForm.firetype = ''
                    for(let i in form){
                        if(form[i].type === '受限空间作业'){
                            this.$refs.taskBasic.activeNames.push('1')
                            this.$refs.taskBasic.ifIncludeArea = 1
                            this.$refs.taskBasic.taskBasicForm.spacecategory = form[i].spacecategory
                            this.$refs.taskBasic.taskBasicForm.spacename = form[i].spacename
                            this.$refs.taskBasic.taskBasicForm.spacemedium = form[i].spacemedium
                            this.$refs.taskBasic.taskBasicForm.acibase = form[i].acibase
                        }
                        else if(form[i].type === '吊装作业'){
                            this.$refs.taskBasic.activeNames.push('2')
                            this.$refs.taskBasic.ifHoisting = 1
                            this.$refs.taskBasic.taskBasicForm.hoistinglevel = form[i].hoistinglevel
                            this.$refs.taskBasic.taskBasicForm.hoistingweight = form[i].hoistingweight
                        }
                        else if(form[i].type === '动土作业'){
                            this.$refs.taskBasic.activeNames.push('3')
                            this.$refs.taskBasic.ifBuilding = 1
                            this.$refs.taskBasic.taskBasicForm.soildepth = form[i].soildepth
                            this.$refs.taskBasic.taskBasicForm.soilarea = form[i].soilarea
                            this.$refs.taskBasic.taskBasicForm.soilfile = form[i].soilfile.map(item =>{
                                return Object.assign(item,{url:process.env.IMG_API + item.fileurl})
                            })
                        }
                        else if(form[i].type === '断路作业'){
                            this.$refs.taskBasic.activeNames.push('4')
                            this.$refs.taskBasic.ifIncludeRoad = 1
                            this.$refs.taskBasic.taskBasicForm.breakreason = form[i].breakreason
                            this.$refs.taskBasic.taskBasicForm.breakfile = form[i].breakfile.map(item =>{
                                return Object.assign(item,{url:process.env.IMG_API + item.fileurl})
                            })
                        }
                        else if(form[i].type === '高处作业'){
                            this.$refs.taskBasic.activeNames.push('5')
                            this.$refs.taskBasic.ifIncludeHigh = 1
                            this.$refs.taskBasic.taskBasicForm.heightlevel = form[i].heightlevel
                            this.$refs.taskBasic.taskBasicForm.workheight = form[i].workheight
                        }
                        else if(form[i].type === '临时用电作业'){
                            this.$refs.taskBasic.activeNames.push('6')
                            this.$refs.taskBasic.ifIncludeElectricity = 1
                            this.$refs.taskBasic.taskBasicForm.electricityarea = form[i].electricityarea
                            this.$refs.taskBasic.taskBasicForm.voltage = form[i].voltage
                            this.$refs.taskBasic.taskBasicForm.power = form[i].power
                        }
                        else if(form[i].type === '盲板抽堵作业'){
                            this.$refs.taskBasic.activeNames.push('7')
                            this.$refs.taskBasic.ifIncludePump = 1
                            this.$refs.taskBasic.taskBasicForm.pipename = form[i].pipename
                            this.$refs.taskBasic.taskBasicForm.pipemedium = form[i].pipemedium
                            this.$refs.taskBasic.taskBasicForm.pipetemperature = form[i].pipetemperature
                            this.$refs.taskBasic.taskBasicForm.pipepressure = form[i].pipepressure
                            this.$refs.taskBasic.taskBasicForm.blindboardmaterial = form[i].blindboardmaterial
                            this.$refs.taskBasic.taskBasicForm.blindboardspecification = form[i].blindboardspecification
                            this.$refs.taskBasic.taskBasicForm.blindboardnumber = form[i].blindboardnumber
                            this.$refs.taskBasic.taskBasicForm.blindboardlocation = form[i].blindboardlocation.map(item =>{
                                return Object.assign(item,{url:process.env.IMG_API + item.fileurl})
                            })
                        }
                        else{
                            this.$refs.taskBasic.activeNames.push('8')
                            this.$refs.taskBasic.ifIncludeFire = 1
                            this.$refs.taskBasic.taskBasicForm.firelevel = form[i].level
                            this.$refs.taskBasic.taskBasicForm.firetype = form[i].firetype
                        }
                    }
                    this.$refs.taskBasic.giveTaskBasic(this.$refs.taskBasic.taskBasicForm)
                })
            }
            else if(title === '复制'){
                this.ifSafetyAction = false
                this.ifSafetyAndRisk = false
                this.ifFireMan = false
                this.ifFile = false
                this.ifConstructionFile = false
                this.ifAllFile = false
                this.ifHotFireBasic = true
                this.basicForm = JSON.parse(JSON.stringify(value))
                setTimeout(()=>{
                    this.$refs.taskBasic.type = 1
                    this.$refs.taskBasic.resetFormRules()
                    this.$refs.taskBasic.taskBasicForm = JSON.parse(JSON.stringify(value))
                    this.$refs.taskBasic.taskBasicForm.hazard = this.$refs.taskBasic.taskBasicForm.hazard.split('、')
                    let form = JSON.parse(JSON.stringify(value)).subTaskInfos
                    this.$refs.taskBasic.taskBasicForm.type = ''
                    this.$refs.taskBasic.taskBasicForm.category = ''
                    this.$refs.taskBasic.taskBasicForm.firelevel = ''
                    this.$refs.taskBasic.taskBasicForm.checked = ''
                    this.$refs.taskBasic.taskBasicForm.spacecategory = ''
                    this.$refs.taskBasic.taskBasicForm.spacename = ''
                    this.$refs.taskBasic.taskBasicForm.spacemedium = ''
                    this.$refs.taskBasic.taskBasicForm.acibase = ''
                    this.$refs.taskBasic.taskBasicForm.hoistinglevel = ''
                    this.$refs.taskBasic.taskBasicForm.hoistingweight = ''
                    this.$refs.taskBasic.taskBasicForm.soildepth = ''
                    this.$refs.taskBasic.taskBasicForm.soilarea = ''
                    this.$refs.taskBasic.taskBasicForm.soilfile = []
                    this.$refs.taskBasic.taskBasicForm.breakreason = ''
                    this.$refs.taskBasic.taskBasicForm.breakfile = []
                    this.$refs.taskBasic.taskBasicForm.workheight = ''
                    this.$refs.taskBasic.taskBasicForm.heightlevel = ''
                    this.$refs.taskBasic.taskBasicForm.electricityarea = ''
                    this.$refs.taskBasic.taskBasicForm.voltage = ''
                    this.$refs.taskBasic.taskBasicForm.power = ''
                    this.$refs.taskBasic.taskBasicForm.pipename = ''
                    this.$refs.taskBasic.taskBasicForm.pipemedium = ''
                    this.$refs.taskBasic.taskBasicForm.pipetemperature = ''
                    this.$refs.taskBasic.taskBasicForm.pipepressure = ''
                    this.$refs.taskBasic.taskBasicForm.blindboardmaterial = ''
                    this.$refs.taskBasic.taskBasicForm.blindboardspecification = ''
                    this.$refs.taskBasic.taskBasicForm.blindboardnumber = ''
                    this.$refs.taskBasic.taskBasicForm.commander = ''
                    this.$refs.taskBasic.taskBasicForm.blindboardlocation = []
                    this.$refs.taskBasic.taskBasicForm.firetype = ''
                    for(let i in form){
                        if(form[i].type === '受限空间作业'){
                            this.$refs.taskBasic.activeNames.push('1')
                            this.$refs.taskBasic.ifIncludeArea = 1
                            this.$refs.taskBasic.taskBasicForm.spacecategory = form[i].spacecategory
                            this.$refs.taskBasic.taskBasicForm.spacename = form[i].spacename
                            this.$refs.taskBasic.taskBasicForm.spacemedium = form[i].spacemedium
                            this.$refs.taskBasic.taskBasicForm.acibase = form[i].acibase
                        }
                        else if(form[i].type === '吊装作业'){
                            this.$refs.taskBasic.activeNames.push('2')
                            this.$refs.taskBasic.ifHoisting = 1
                            this.$refs.taskBasic.taskBasicForm.hoistinglevel = form[i].hoistinglevel
                            this.$refs.taskBasic.taskBasicForm.hoistingweight = form[i].hoistingweight
                        }
                        else if(form[i].type === '动土作业'){
                            this.$refs.taskBasic.activeNames.push('3')
                            this.$refs.taskBasic.ifBuilding = 1
                            this.$refs.taskBasic.taskBasicForm.soildepth = form[i].soildepth
                            this.$refs.taskBasic.taskBasicForm.soilarea = form[i].soilarea
                            this.$refs.taskBasic.taskBasicForm.soilfile = form[i].soilfile.map(item =>{
                                return Object.assign(item,{url:process.env.IMG_API + item.fileurl})
                            })
                        }
                        else if(form[i].type === '断路作业'){
                            this.$refs.taskBasic.activeNames.push('4')
                            this.$refs.taskBasic.ifIncludeRoad = 1
                            this.$refs.taskBasic.taskBasicForm.breakreason = form[i].breakreason
                            this.$refs.taskBasic.taskBasicForm.breakfile = form[i].breakfile.map(item =>{
                                return Object.assign(item,{url:process.env.IMG_API + item.fileurl})
                            })
                        }
                        else if(form[i].type === '高处作业'){
                            this.$refs.taskBasic.activeNames.push('5')
                            this.$refs.taskBasic.ifIncludeHigh = 1
                            this.$refs.taskBasic.taskBasicForm.heightlevel = form[i].heightlevel
                            this.$refs.taskBasic.taskBasicForm.workheight = form[i].workheight
                        }
                        else if(form[i].type === '临时用电作业'){
                            this.$refs.taskBasic.activeNames.push('6')
                            this.$refs.taskBasic.ifIncludeElectricity = 1
                            this.$refs.taskBasic.taskBasicForm.electricityarea = form[i].electricityarea
                            this.$refs.taskBasic.taskBasicForm.voltage = form[i].voltage
                            this.$refs.taskBasic.taskBasicForm.power = form[i].power
                        }
                        else if(form[i].type === '盲板抽堵作业'){
                            this.$refs.taskBasic.activeNames.push('7')
                            this.$refs.taskBasic.ifIncludePump = 1
                            this.$refs.taskBasic.taskBasicForm.pipename = form[i].pipename
                            this.$refs.taskBasic.taskBasicForm.pipemedium = form[i].pipemedium
                            this.$refs.taskBasic.taskBasicForm.pipetemperature = form[i].pipetemperature
                            this.$refs.taskBasic.taskBasicForm.pipepressure = form[i].pipepressure
                            this.$refs.taskBasic.taskBasicForm.blindboardmaterial = form[i].blindboardmaterial
                            this.$refs.taskBasic.taskBasicForm.blindboardspecification = form[i].blindboardspecification
                            this.$refs.taskBasic.taskBasicForm.blindboardnumber = form[i].blindboardnumber
                            this.$refs.taskBasic.taskBasicForm.blindboardlocation = form[i].blindboardlocation.map(item =>{
                                return Object.assign(item,{url:process.env.IMG_API + item.fileurl})
                            })
                        }
                        else{
                            this.$refs.taskBasic.activeNames.push('8')
                            this.$refs.taskBasic.ifIncludeFire = 1
                            this.$refs.taskBasic.taskBasicForm.firelevel = form[i].level
                            this.$refs.taskBasic.taskBasicForm.firetype = form[i].firetype
                        }
                    }
                    this.$refs.taskBasic.giveTaskBasic(this.$refs.taskBasic.taskBasicForm)
                })
            }
            else if(title === '施工单位确认'){
                this.title = '施工单位确认'
                this.ifHotFireBasic = true
                this.ifSafetyAction = true
                this.ifSafetyAndRisk = true
                this.ifFireMan = false
                this.ifFile = false
                this.ifConstructionFile = true
                this.basicForm = JSON.parse(JSON.stringify(value))
                setTimeout(()=>{
                    this.$refs.taskBasic.taskBasicForm = JSON.parse(JSON.stringify(value))
                    this.$refs.taskBasic.taskBasicForm.hazard = this.$refs.taskBasic.taskBasicForm.hazard.split(',')
                    let form = JSON.parse(JSON.stringify(value)).subTaskInfos
                    this.$refs.taskBasic.taskBasicForm.type = ''
                    this.$refs.taskBasic.taskBasicForm.category = ''
                    this.$refs.taskBasic.taskBasicForm.firelevel = ''
                    this.$refs.taskBasic.taskBasicForm.checked = ''
                    this.$refs.taskBasic.taskBasicForm.spacecategory = ''
                    this.$refs.taskBasic.taskBasicForm.spacename = ''
                    this.$refs.taskBasic.taskBasicForm.spacemedium = ''
                    this.$refs.taskBasic.taskBasicForm.acibase = ''
                    this.$refs.taskBasic.taskBasicForm.hoistinglevel = ''
                    this.$refs.taskBasic.taskBasicForm.hoistingweight = ''
                    this.$refs.taskBasic.taskBasicForm.soildepth = ''
                    this.$refs.taskBasic.taskBasicForm.soilarea = ''
                    this.$refs.taskBasic.taskBasicForm.soilfile = []
                    this.$refs.taskBasic.taskBasicForm.breakreason = ''
                    this.$refs.taskBasic.taskBasicForm.breakfile = []
                    this.$refs.taskBasic.taskBasicForm.workheight = ''
                    this.$refs.taskBasic.taskBasicForm.heightlevel = ''
                    this.$refs.taskBasic.taskBasicForm.electricityarea = ''
                    this.$refs.taskBasic.taskBasicForm.voltage = ''
                    this.$refs.taskBasic.taskBasicForm.power = ''
                    this.$refs.taskBasic.taskBasicForm.pipename = ''
                    this.$refs.taskBasic.taskBasicForm.pipemedium = ''
                    this.$refs.taskBasic.taskBasicForm.pipetemperature = ''
                    this.$refs.taskBasic.taskBasicForm.pipepressure = ''
                    this.$refs.taskBasic.taskBasicForm.blindboardmaterial = ''
                    this.$refs.taskBasic.taskBasicForm.blindboardspecification = ''
                    this.$refs.taskBasic.taskBasicForm.blindboardnumber = ''
                    this.$refs.taskBasic.taskBasicForm.commander = ''
                    this.$refs.taskBasic.taskBasicForm.blindboardlocation = []
                    this.$refs.taskBasic.taskBasicForm.firetype = ''
                    for(let i in form){
                        if(form[i].type === '受限空间作业'){
                            this.$refs.taskBasic.activeNames.push('1')
                            this.$refs.taskBasic.ifIncludeArea = 1
                            this.$refs.taskBasic.taskBasicForm.spacecategory = form[i].spacecategory
                            this.$refs.taskBasic.taskBasicForm.spacename = form[i].spacename
                            this.$refs.taskBasic.taskBasicForm.spacemedium = form[i].spacemedium
                            this.$refs.taskBasic.taskBasicForm.acibase = form[i].acibase
                        }
                        else if(form[i].type === '吊装作业'){
                            this.$refs.taskBasic.activeNames.push('2')
                            this.$refs.taskBasic.ifHoisting = 1
                            this.$refs.taskBasic.taskBasicForm.hoistinglevel = form[i].hoistinglevel
                            this.$refs.taskBasic.taskBasicForm.hoistingweight = form[i].hoistingweight
                        }
                        else if(form[i].type === '动土作业'){
                            this.$refs.taskBasic.activeNames.push('3')
                            this.$refs.taskBasic.ifBuilding = 1
                            this.$refs.taskBasic.taskBasicForm.soildepth = form[i].soildepth
                            this.$refs.taskBasic.taskBasicForm.soilarea = form[i].soilarea
                            this.$refs.taskBasic.taskBasicForm.soilfile = form[i].soilfile.map(item =>{
                                return Object.assign(item,{url:process.env.IMG_API + item.fileurl})
                            })
                        }
                        else if(form[i].type === '断路作业'){
                            this.$refs.taskBasic.activeNames.push('4')
                            this.$refs.taskBasic.ifIncludeRoad = 1
                            this.$refs.taskBasic.taskBasicForm.breakreason = form[i].breakreason
                            this.$refs.taskBasic.taskBasicForm.breakfile = form[i].breakfile.map(item =>{
                                return Object.assign(item,{url:process.env.IMG_API + item.fileurl})
                            })
                        }
                        else if(form[i].type === '高处作业'){
                            this.$refs.taskBasic.activeNames.push('5')
                            this.$refs.taskBasic.ifIncludeHigh = 1
                            this.$refs.taskBasic.taskBasicForm.heightlevel = form[i].heightlevel
                            this.$refs.taskBasic.taskBasicForm.workheight = form[i].workheight
                        }
                        else if(form[i].type === '临时用电作业'){
                            this.$refs.taskBasic.activeNames.push('6')
                            this.$refs.taskBasic.ifIncludeElectricity = 1
                            this.$refs.taskBasic.taskBasicForm.electricityarea = form[i].electricityarea
                            this.$refs.taskBasic.taskBasicForm.voltage = form[i].voltage
                            this.$refs.taskBasic.taskBasicForm.power = form[i].power
                        }
                        else if(form[i].type === '盲板抽堵作业'){
                            this.$refs.taskBasic.activeNames.push('7')
                            this.$refs.taskBasic.ifIncludePump = 1
                            this.$refs.taskBasic.taskBasicForm.pipename = form[i].pipename
                            this.$refs.taskBasic.taskBasicForm.pipemedium = form[i].pipemedium
                            this.$refs.taskBasic.taskBasicForm.pipetemperature = form[i].pipetemperature
                            this.$refs.taskBasic.taskBasicForm.pipepressure = form[i].pipepressure
                            this.$refs.taskBasic.taskBasicForm.blindboardmaterial = form[i].blindboardmaterial
                            this.$refs.taskBasic.taskBasicForm.blindboardspecification = form[i].blindboardspecification
                            this.$refs.taskBasic.taskBasicForm.blindboardnumber = form[i].blindboardnumber
                            this.$refs.taskBasic.taskBasicForm.blindboardlocation = form[i].blindboardlocation.map(item =>{
                                return Object.assign(item,{url:process.env.IMG_API + item.fileurl})
                            })
                        }
                        else{
                            this.$refs.taskBasic.activeNames.push('8')
                            this.$refs.taskBasic.ifIncludeFire = 1
                            this.$refs.taskBasic.taskBasicForm.firelevel = form[i].level
                            this.$refs.taskBasic.taskBasicForm.firetype = form[i].firetype
                        }
                    }
                    this.$refs.safetyAction.tasksecurity = JSON.parse(JSON.stringify(value)).taskSecurities
                    this.$refs.safetyAndRiskConfirm.taskRiskForm = JSON.parse(JSON.stringify(value)).taskRisk
                    this.$refs.equipment.equipmentData = JSON.parse(JSON.stringify(value)).taskEquipments
                    this.$refs.constructionFile.ifCompany = true
                    this.$refs.constructionFile.ifConstruction = false
                    this.$refs.constructionFile.getFileList()
                    this.$refs.taskBasic.resetFormRules()
                })
            }
            else if(title === '动火部位审批'){
                this.ifHotFireBasic = true
                this.ifSafetyAction = true
                this.ifSafetyAndRisk = true
                this.ifFireMan = true
                this.ifAllFile = true
                this.basicForm = JSON.parse(JSON.stringify(value))
                setTimeout(()=>{
                    this.$refs.taskBasic.taskBasicForm = JSON.parse(JSON.stringify(value))
                    let form = JSON.parse(JSON.stringify(value)).subTaskInfos
                    this.$refs.taskBasic.taskBasicForm.type = ''
                    this.$refs.taskBasic.taskBasicForm.category = ''
                    this.$refs.taskBasic.taskBasicForm.firelevel = ''
                    this.$refs.taskBasic.taskBasicForm.checked = ''
                    this.$refs.taskBasic.taskBasicForm.spacecategory = ''
                    this.$refs.taskBasic.taskBasicForm.spacename = ''
                    this.$refs.taskBasic.taskBasicForm.spacemedium = ''
                    this.$refs.taskBasic.taskBasicForm.acibase = ''
                    this.$refs.taskBasic.taskBasicForm.hoistinglevel = ''
                    this.$refs.taskBasic.taskBasicForm.hoistingweight = ''
                    this.$refs.taskBasic.taskBasicForm.soildepth = ''
                    this.$refs.taskBasic.taskBasicForm.soilarea = ''
                    this.$refs.taskBasic.taskBasicForm.soilfile = []
                    this.$refs.taskBasic.taskBasicForm.breakreason = ''
                    this.$refs.taskBasic.taskBasicForm.breakfile = []
                    this.$refs.taskBasic.taskBasicForm.workheight = ''
                    this.$refs.taskBasic.taskBasicForm.heightlevel = ''
                    this.$refs.taskBasic.taskBasicForm.electricityarea = ''
                    this.$refs.taskBasic.taskBasicForm.voltage = ''
                    this.$refs.taskBasic.taskBasicForm.power = ''
                    this.$refs.taskBasic.taskBasicForm.pipename = ''
                    this.$refs.taskBasic.taskBasicForm.pipemedium = ''
                    this.$refs.taskBasic.taskBasicForm.pipetemperature = ''
                    this.$refs.taskBasic.taskBasicForm.pipepressure = ''
                    this.$refs.taskBasic.taskBasicForm.blindboardmaterial = ''
                    this.$refs.taskBasic.taskBasicForm.blindboardspecification = ''
                    this.$refs.taskBasic.taskBasicForm.blindboardnumber = ''
                    this.$refs.taskBasic.taskBasicForm.commander = ''
                    this.$refs.taskBasic.taskBasicForm.blindboardlocation = []
                    this.$refs.taskBasic.taskBasicForm.firetype = ''
                    for(let i in form){
                        if(form[i].type === '受限空间作业'){
                            this.$refs.taskBasic.activeNames.push('1')
                            this.$refs.taskBasic.ifIncludeArea = 1
                            this.$refs.taskBasic.taskBasicForm.spacecategory = form[i].spacecategory
                            this.$refs.taskBasic.taskBasicForm.spacename = form[i].spacename
                            this.$refs.taskBasic.taskBasicForm.spacemedium = form[i].spacemedium
                            this.$refs.taskBasic.taskBasicForm.acibase = form[i].acibase
                        }
                        else if(form[i].type === '吊装作业'){
                            this.$refs.taskBasic.activeNames.push('2')
                            this.$refs.taskBasic.ifHoisting = 1
                            this.$refs.taskBasic.taskBasicForm.hoistinglevel = form[i].hoistinglevel
                            this.$refs.taskBasic.taskBasicForm.hoistingweight = form[i].hoistingweight
                        }
                        else if(form[i].type === '动土作业'){
                            this.$refs.taskBasic.activeNames.push('3')
                            this.$refs.taskBasic.ifBuilding = 1
                            this.$refs.taskBasic.taskBasicForm.soildepth = form[i].soildepth
                            this.$refs.taskBasic.taskBasicForm.soilarea = form[i].soilarea
                            this.$refs.taskBasic.taskBasicForm.soilfile = form[i].soilfile.map(item =>{
                                return Object.assign(item,{url:process.env.IMG_API + item.fileurl})
                            })
                        }
                        else if(form[i].type === '断路作业'){
                            this.$refs.taskBasic.activeNames.push('4')
                            this.$refs.taskBasic.ifIncludeRoad = 1
                            this.$refs.taskBasic.taskBasicForm.breakreason = form[i].breakreason
                            this.$refs.taskBasic.taskBasicForm.breakfile = form[i].breakfile.map(item =>{
                                return Object.assign(item,{url:process.env.IMG_API + item.fileurl})
                            })
                        }
                        else if(form[i].type === '高处作业'){
                            this.$refs.taskBasic.activeNames.push('5')
                            this.$refs.taskBasic.ifIncludeHigh = 1
                            this.$refs.taskBasic.taskBasicForm.heightlevel = form[i].heightlevel
                            this.$refs.taskBasic.taskBasicForm.workheight = form[i].workheight
                        }
                        else if(form[i].type === '临时用电作业'){
                            this.$refs.taskBasic.activeNames.push('6')
                            this.$refs.taskBasic.ifIncludeElectricity = 1
                            this.$refs.taskBasic.taskBasicForm.electricityarea = form[i].electricityarea
                            this.$refs.taskBasic.taskBasicForm.voltage = form[i].voltage
                            this.$refs.taskBasic.taskBasicForm.power = form[i].power
                        }
                        else if(form[i].type === '盲板抽堵作业'){
                            this.$refs.taskBasic.activeNames.push('7')
                            this.$refs.taskBasic.ifIncludePump = 1
                            this.$refs.taskBasic.taskBasicForm.pipename = form[i].pipename
                            this.$refs.taskBasic.taskBasicForm.pipemedium = form[i].pipemedium
                            this.$refs.taskBasic.taskBasicForm.pipetemperature = form[i].pipetemperature
                            this.$refs.taskBasic.taskBasicForm.pipepressure = form[i].pipepressure
                            this.$refs.taskBasic.taskBasicForm.blindboardmaterial = form[i].blindboardmaterial
                            this.$refs.taskBasic.taskBasicForm.blindboardspecification = form[i].blindboardspecification
                            this.$refs.taskBasic.taskBasicForm.blindboardnumber = form[i].blindboardnumber
                            this.$refs.taskBasic.taskBasicForm.blindboardlocation = form[i].blindboardlocation.map(item =>{
                                return Object.assign(item,{url:process.env.IMG_API + item.fileurl})
                            })
                        }
                        else{
                            this.$refs.taskBasic.activeNames.push('8')
                            this.$refs.taskBasic.ifIncludeFire = 1
                            this.$refs.taskBasic.taskBasicForm.firelevel = form[i].level
                            this.$refs.taskBasic.taskBasicForm.firetype = form[i].firetype
                        }
                    }
                    this.$refs.safetyAction.tasksecurity = JSON.parse(JSON.stringify(value)).taskSecurities
                    this.$refs.safetyAndRiskConfirm.taskRiskForm = JSON.parse(JSON.stringify(value)).taskRisk
                    this.$refs.equipment.equipmentData = JSON.parse(JSON.stringify(value)).taskEquipments
                    this.$refs.fireMan.taskWorkers = JSON.parse(JSON.stringify(value)).taskWorkers
                    this.$refs.taskBasic.resetFormRules()
                })
            }
            else if(title === '相关部门审批'){
                this.ifHotFireBasic = true
                this.ifSafetyAction = true
                this.ifSafetyAndRisk = true
                this.ifFireMan = true
                this.ifAllFile = true
                this.basicForm = JSON.parse(JSON.stringify(value))
                setTimeout(()=>{
                    this.$refs.taskBasic.taskBasicForm = JSON.parse(JSON.stringify(value))
                    let form = JSON.parse(JSON.stringify(value)).subTaskInfos
                    this.$refs.taskBasic.taskBasicForm.type = ''
                    this.$refs.taskBasic.taskBasicForm.category = ''
                    this.$refs.taskBasic.taskBasicForm.firelevel = ''
                    this.$refs.taskBasic.taskBasicForm.checked = ''
                    this.$refs.taskBasic.taskBasicForm.spacecategory = ''
                    this.$refs.taskBasic.taskBasicForm.spacename = ''
                    this.$refs.taskBasic.taskBasicForm.spacemedium = ''
                    this.$refs.taskBasic.taskBasicForm.acibase = ''
                    this.$refs.taskBasic.taskBasicForm.hoistinglevel = ''
                    this.$refs.taskBasic.taskBasicForm.hoistingweight = ''
                    this.$refs.taskBasic.taskBasicForm.soildepth = ''
                    this.$refs.taskBasic.taskBasicForm.soilarea = ''
                    this.$refs.taskBasic.taskBasicForm.soilfile = []
                    this.$refs.taskBasic.taskBasicForm.breakreason = ''
                    this.$refs.taskBasic.taskBasicForm.breakfile = []
                    this.$refs.taskBasic.taskBasicForm.workheight = ''
                    this.$refs.taskBasic.taskBasicForm.heightlevel = ''
                    this.$refs.taskBasic.taskBasicForm.electricityarea = ''
                    this.$refs.taskBasic.taskBasicForm.voltage = ''
                    this.$refs.taskBasic.taskBasicForm.power = ''
                    this.$refs.taskBasic.taskBasicForm.pipename = ''
                    this.$refs.taskBasic.taskBasicForm.pipemedium = ''
                    this.$refs.taskBasic.taskBasicForm.pipetemperature = ''
                    this.$refs.taskBasic.taskBasicForm.pipepressure = ''
                    this.$refs.taskBasic.taskBasicForm.blindboardmaterial = ''
                    this.$refs.taskBasic.taskBasicForm.blindboardspecification = ''
                    this.$refs.taskBasic.taskBasicForm.blindboardnumber = ''
                    this.$refs.taskBasic.taskBasicForm.commander = ''
                    this.$refs.taskBasic.taskBasicForm.blindboardlocation = []
                    this.$refs.taskBasic.taskBasicForm.firetype = ''
                    for(let i in form){
                        if(form[i].type === '受限空间作业'){
                            this.$refs.taskBasic.activeNames.push('1')
                            this.$refs.taskBasic.ifIncludeArea = 1
                            this.$refs.taskBasic.taskBasicForm.spacecategory = form[i].spacecategory
                            this.$refs.taskBasic.taskBasicForm.spacename = form[i].spacename
                            this.$refs.taskBasic.taskBasicForm.spacemedium = form[i].spacemedium
                            this.$refs.taskBasic.taskBasicForm.acibase = form[i].acibase
                        }
                        else if(form[i].type === '吊装作业'){
                            this.$refs.taskBasic.activeNames.push('2')
                            this.$refs.taskBasic.ifHoisting = 1
                            this.$refs.taskBasic.taskBasicForm.hoistinglevel = form[i].hoistinglevel
                            this.$refs.taskBasic.taskBasicForm.hoistingweight = form[i].hoistingweight
                        }
                        else if(form[i].type === '动土作业'){
                            this.$refs.taskBasic.activeNames.push('3')
                            this.$refs.taskBasic.ifBuilding = 1
                            this.$refs.taskBasic.taskBasicForm.soildepth = form[i].soildepth
                            this.$refs.taskBasic.taskBasicForm.soilarea = form[i].soilarea
                            this.$refs.taskBasic.taskBasicForm.soilfile = form[i].soilfile.map(item =>{
                                return Object.assign(item,{url:process.env.IMG_API + item.fileurl})
                            })
                        }
                        else if(form[i].type === '断路作业'){
                            this.$refs.taskBasic.activeNames.push('4')
                            this.$refs.taskBasic.ifIncludeRoad = 1
                            this.$refs.taskBasic.taskBasicForm.breakreason = form[i].breakreason
                            this.$refs.taskBasic.taskBasicForm.breakfile = form[i].breakfile.map(item =>{
                                return Object.assign(item,{url:process.env.IMG_API + item.fileurl})
                            })
                        }
                        else if(form[i].type === '高处作业'){
                            this.$refs.taskBasic.activeNames.push('5')
                            this.$refs.taskBasic.ifIncludeHigh = 1
                            this.$refs.taskBasic.taskBasicForm.heightlevel = form[i].heightlevel
                            this.$refs.taskBasic.taskBasicForm.workheight = form[i].workheight
                        }
                        else if(form[i].type === '临时用电作业'){
                            this.$refs.taskBasic.activeNames.push('6')
                            this.$refs.taskBasic.ifIncludeElectricity = 1
                            this.$refs.taskBasic.taskBasicForm.electricityarea = form[i].electricityarea
                            this.$refs.taskBasic.taskBasicForm.voltage = form[i].voltage
                            this.$refs.taskBasic.taskBasicForm.power = form[i].power
                        }
                        else if(form[i].type === '盲板抽堵作业'){
                            this.$refs.taskBasic.activeNames.push('7')
                            this.$refs.taskBasic.ifIncludePump = 1
                            this.$refs.taskBasic.taskBasicForm.pipename = form[i].pipename
                            this.$refs.taskBasic.taskBasicForm.pipemedium = form[i].pipemedium
                            this.$refs.taskBasic.taskBasicForm.pipetemperature = form[i].pipetemperature
                            this.$refs.taskBasic.taskBasicForm.pipepressure = form[i].pipepressure
                            this.$refs.taskBasic.taskBasicForm.blindboardmaterial = form[i].blindboardmaterial
                            this.$refs.taskBasic.taskBasicForm.blindboardspecification = form[i].blindboardspecification
                            this.$refs.taskBasic.taskBasicForm.blindboardnumber = form[i].blindboardnumber
                            this.$refs.taskBasic.taskBasicForm.blindboardlocation = form[i].blindboardlocation.map(item =>{
                                return Object.assign(item,{url:process.env.IMG_API + item.fileurl})
                            })
                        }
                        else{
                            this.$refs.taskBasic.activeNames.push('8')
                            this.$refs.taskBasic.ifIncludeFire = 1
                            this.$refs.taskBasic.taskBasicForm.firelevel = form[i].level
                            this.$refs.taskBasic.taskBasicForm.firetype = form[i].firetype
                        }
                    }
                    this.$refs.safetyAction.tasksecurity = JSON.parse(JSON.stringify(value)).taskSecurities
                    this.$refs.safetyAndRiskConfirm.taskRiskForm = JSON.parse(JSON.stringify(value)).taskRisk
                    this.$refs.equipment.equipmentData = JSON.parse(JSON.stringify(value)).taskEquipments
                    this.$refs.fireMan.taskWorkers = JSON.parse(JSON.stringify(value)).taskWorkers
                    this.$refs.taskBasic.resetFormRules()
                })
            }
            else if(title === '安全部门审批'){
                this.ifHotFireBasic = true
                this.ifSafetyAction = true
                this.ifSafetyAndRisk = true
                this.ifFireMan = true
                this.ifAllFile = true
                this.basicForm = JSON.parse(JSON.stringify(value))
                setTimeout(()=>{
                    this.$refs.taskBasic.taskBasicForm = JSON.parse(JSON.stringify(value))
                    let form = JSON.parse(JSON.stringify(value)).subTaskInfos
                    this.$refs.taskBasic.taskBasicForm.type = ''
                    this.$refs.taskBasic.taskBasicForm.category = ''
                    this.$refs.taskBasic.taskBasicForm.firelevel = ''
                    this.$refs.taskBasic.taskBasicForm.checked = ''
                    this.$refs.taskBasic.taskBasicForm.spacecategory = ''
                    this.$refs.taskBasic.taskBasicForm.spacename = ''
                    this.$refs.taskBasic.taskBasicForm.spacemedium = ''
                    this.$refs.taskBasic.taskBasicForm.acibase = ''
                    this.$refs.taskBasic.taskBasicForm.hoistinglevel = ''
                    this.$refs.taskBasic.taskBasicForm.hoistingweight = ''
                    this.$refs.taskBasic.taskBasicForm.soildepth = ''
                    this.$refs.taskBasic.taskBasicForm.soilarea = ''
                    this.$refs.taskBasic.taskBasicForm.soilfile = []
                    this.$refs.taskBasic.taskBasicForm.breakreason = ''
                    this.$refs.taskBasic.taskBasicForm.breakfile = []
                    this.$refs.taskBasic.taskBasicForm.workheight = ''
                    this.$refs.taskBasic.taskBasicForm.heightlevel = ''
                    this.$refs.taskBasic.taskBasicForm.electricityarea = ''
                    this.$refs.taskBasic.taskBasicForm.voltage = ''
                    this.$refs.taskBasic.taskBasicForm.power = ''
                    this.$refs.taskBasic.taskBasicForm.pipename = ''
                    this.$refs.taskBasic.taskBasicForm.pipemedium = ''
                    this.$refs.taskBasic.taskBasicForm.pipetemperature = ''
                    this.$refs.taskBasic.taskBasicForm.pipepressure = ''
                    this.$refs.taskBasic.taskBasicForm.blindboardmaterial = ''
                    this.$refs.taskBasic.taskBasicForm.blindboardspecification = ''
                    this.$refs.taskBasic.taskBasicForm.blindboardnumber = ''
                    this.$refs.taskBasic.taskBasicForm.commander = ''
                    this.$refs.taskBasic.taskBasicForm.blindboardlocation = []
                    this.$refs.taskBasic.taskBasicForm.firetype = ''
                    for(let i in form){
                        if(form[i].type === '受限空间作业'){
                            this.$refs.taskBasic.activeNames.push('1')
                            this.$refs.taskBasic.ifIncludeArea = 1
                            this.$refs.taskBasic.taskBasicForm.spacecategory = form[i].spacecategory
                            this.$refs.taskBasic.taskBasicForm.spacename = form[i].spacename
                            this.$refs.taskBasic.taskBasicForm.spacemedium = form[i].spacemedium
                            this.$refs.taskBasic.taskBasicForm.acibase = form[i].acibase
                        }
                        else if(form[i].type === '吊装作业'){
                            this.$refs.taskBasic.activeNames.push('2')
                            this.$refs.taskBasic.ifHoisting = 1
                            this.$refs.taskBasic.taskBasicForm.hoistinglevel = form[i].hoistinglevel
                            this.$refs.taskBasic.taskBasicForm.hoistingweight = form[i].hoistingweight
                        }
                        else if(form[i].type === '动土作业'){
                            this.$refs.taskBasic.activeNames.push('3')
                            this.$refs.taskBasic.ifBuilding = 1
                            this.$refs.taskBasic.taskBasicForm.soildepth = form[i].soildepth
                            this.$refs.taskBasic.taskBasicForm.soilarea = form[i].soilarea
                            this.$refs.taskBasic.taskBasicForm.soilfile = form[i].soilfile.map(item =>{
                                return Object.assign(item,{url:process.env.IMG_API + item.fileurl})
                            })
                        }
                        else if(form[i].type === '断路作业'){
                            this.$refs.taskBasic.activeNames.push('4')
                            this.$refs.taskBasic.ifIncludeRoad = 1
                            this.$refs.taskBasic.taskBasicForm.breakreason = form[i].breakreason
                            this.$refs.taskBasic.taskBasicForm.breakfile = form[i].breakfile.map(item =>{
                                return Object.assign(item,{url:process.env.IMG_API + item.fileurl})
                            })
                        }
                        else if(form[i].type === '高处作业'){
                            this.$refs.taskBasic.activeNames.push('5')
                            this.$refs.taskBasic.ifIncludeHigh = 1
                            this.$refs.taskBasic.taskBasicForm.heightlevel = form[i].heightlevel
                            this.$refs.taskBasic.taskBasicForm.workheight = form[i].workheight
                        }
                        else if(form[i].type === '临时用电作业'){
                            this.$refs.taskBasic.activeNames.push('6')
                            this.$refs.taskBasic.ifIncludeElectricity = 1
                            this.$refs.taskBasic.taskBasicForm.electricityarea = form[i].electricityarea
                            this.$refs.taskBasic.taskBasicForm.voltage = form[i].voltage
                            this.$refs.taskBasic.taskBasicForm.power = form[i].power
                        }
                        else if(form[i].type === '盲板抽堵作业'){
                            this.$refs.taskBasic.activeNames.push('7')
                            this.$refs.taskBasic.ifIncludePump = 1
                            this.$refs.taskBasic.taskBasicForm.pipename = form[i].pipename
                            this.$refs.taskBasic.taskBasicForm.pipemedium = form[i].pipemedium
                            this.$refs.taskBasic.taskBasicForm.pipetemperature = form[i].pipetemperature
                            this.$refs.taskBasic.taskBasicForm.pipepressure = form[i].pipepressure
                            this.$refs.taskBasic.taskBasicForm.blindboardmaterial = form[i].blindboardmaterial
                            this.$refs.taskBasic.taskBasicForm.blindboardspecification = form[i].blindboardspecification
                            this.$refs.taskBasic.taskBasicForm.blindboardnumber = form[i].blindboardnumber
                            this.$refs.taskBasic.taskBasicForm.blindboardlocation = form[i].blindboardlocation.map(item =>{
                                return Object.assign(item,{url:process.env.IMG_API + item.fileurl})
                            })
                        }
                        else{
                            this.$refs.taskBasic.activeNames.push('8')
                            this.$refs.taskBasic.ifIncludeFire = 1
                            this.$refs.taskBasic.taskBasicForm.firelevel = form[i].level
                            this.$refs.taskBasic.taskBasicForm.firetype = form[i].firetype
                        }
                    }
                    this.$refs.safetyAction.tasksecurity = JSON.parse(JSON.stringify(value)).taskSecurities
                    this.$refs.safetyAndRiskConfirm.taskRiskForm = JSON.parse(JSON.stringify(value)).taskRisk
                    this.$refs.equipment.equipmentData = JSON.parse(JSON.stringify(value)).taskEquipments
                    this.$refs.fireMan.taskWorkers = JSON.parse(JSON.stringify(value)).taskWorkers
                    this.$refs.taskBasic.resetFormRules()
                })
            }
        },
        changeToSecond(val){
            if(val.isanalysis === 1){
                this.taskCreateDialog = false
            }else if(this.title === '新增' || this.title === '编辑' || this.title === '复制'){
                this.ifHotFireBasic = false
                this.ifSafetyAction = true
                this.ifSafetyAndRisk = true
                this.activeName = 'safetyAction'
                this.basicForm = val
                this.$emit('getinfo')
                setTimeout(()=>{
                    if(val.taskSecurities.length === 0){
                        this.$refs.safetyAction.getSafeTyAction()
                    }else{
                        this.$refs.safetyAction.tasksecurity = val.taskSecurities
                    }
                    if(val.taskRisk === null){
                        this.$refs.safetyAndRiskConfirm.taskRiskForm = {
                            id:'',
                            taskcode:'',
                            content:'',
                            environment:'',
                            preventive:'',
                            emergency:'',
                            other:'',
                            director:'',
                            taskdirector:'',
                            confirmat:'',
                            createdat:'',
                            createdby:'',
                            modifiedat:'',
                            modifiedby:'',
                            flag:'',
                        }
                    }else{
                        this.$refs.safetyAndRiskConfirm.taskRiskForm = val.taskRisk
                    }
                    this.$refs.equipment.equipmentData = val.taskEquipments
                })
            }else{
                this.ifHotFireBasic = false
                this.ifSafetyAction = true
                this.ifSafetyAndRisk = true
                this.activeName = 'safetyAction'
                this.$emit('getinfo')
                setTimeout(()=>{
                    this.$refs.safetyAction.tasksecurity = this.basicForm.taskSecurities
                    this.$refs.equipment.equipmentData = this.basicForm.taskEquipments
                    this.$refs.safetyAndRiskConfirm.taskRiskForm = this.basicForm.taskRisk
                })
            }
        },
        async changeToThird(){
            let correct
            for(let i in this.$refs.safetyAction.tasksecurity){
                if(this.$refs.safetyAction.tasksecurity[i].checked === null || this.$refs.safetyAction.tasksecurity[i].checked === undefined || this.$refs.safetyAction.tasksecurity[i].checked === ''){
                    correct = 0
                    this.$message({
                        type:'warning',
                        message:'请完善安全措施'
                    })
                    break
                }else{
                    correct = 1
                }
            }
            if(correct === 1){
                if((this.$refs.safetyAndRiskConfirm.taskRiskForm.content === '' || this.$refs.safetyAndRiskConfirm.taskRiskForm.environment === '' || this.$refs.safetyAndRiskConfirm.taskRiskForm.preventive === '' || this.$refs.safetyAndRiskConfirm.taskRiskForm.emergency === '' || this.$refs.safetyAndRiskConfirm.taskRiskForm.other === '') && this.basicForm.level === 2){
                    this.$message({
                        type:'warning',
                        message:'请完善安全交底和风险告知确认卡'
                    })
                }else if(this.$refs.equipment.equipmentData.length === 0){
                    this.$message({
                        type:'warning',
                        message:'请完善设备'
                    })
                } else{
                    this.basicForm.taskSecurities = this.$refs.safetyAction.tasksecurity
                    this.basicForm.taskRisk = this.$refs.safetyAndRiskConfirm.taskRiskForm
                    this.basicForm.taskRisk.taskcode = this.basicForm.code
                    this.basicForm.taskEquipments = this.$refs.equipment.equipmentData
                    if(this.title === '新增' || this.title === '复制') {
                        let res = await addTaskSecond(this.basicForm)
                        if (res.data.code === '200') {
                            this.ifFile = true
                            this.ifHotFireBasic = false
                            this.ifSafetyAction = false
                            this.ifSafetyAndRisk = false
                            this.activeName = 'fileAndEquipment'
                            this.$notify({
                                title: '成功',
                                duration: 2000,
                                message: '信息上传成功',
                                type: 'success'
                            })
                            this.$emit('getinfo')
                        } else {
                            this.$message({
                                message: res.data.message,
                                type: 'warning'
                            })
                        }
                    }else if(this.title === '编辑'){
                        let res = await updateTaskSecond(this.basicForm)
                        if (res.data.code === '200') {
                            this.ifFile = true
                            this.ifHotFireBasic = false
                            this.ifSafetyAction = false
                            this.ifSafetyAndRisk = false
                            this.activeName = 'fileAndEquipment'
                            this.$notify({
                                title: '成功',
                                duration: 2000,
                                message: '信息上传成功',
                                type: 'success'
                            })
                            this.$emit('getinfo')
                        } else {
                            this.$message({
                                message: res.data.message,
                                type: 'warning'
                            })
                        }
                    }
                }
            }
        },
        confirmFile(){
            if(this.$refs.fileAndEquipment.fileListOne.length === 0){
                this.$message({
                    type:'warning',
                    message:'请上传事故救援预案'
                })
            }else{
                this.taskCreateDialog = false
                this.$notify({
                    title: '成功',
                    duration: 2000,
                    message: '新建成功',
                    type: 'success'
                })
            }

        },
        constructionConfirm(){
            this.title = '施工单位信息填写'
            this.activeName = 'safetyAction'
            this.ifHotFireBasic = false
            this.ifSafetyAction = true
            this.ifSafetyAndRisk = false
            this.ifFireMan = true
            this.ifFile = false
            this.ifConstructionFile = false
            this.constructionForm = {
                id: this.basicForm.id,
                isAgree: 1,
                code:this.basicForm.code,
                taskEquipments:[],
                taskSecurities:[],
                taskWorkers:[]
            }
            setTimeout(()=>{
                this.$refs.equipment.equipmentData = []
                this.$refs.safetyAction.getConstructionAction()
                this.$refs.constructionFile.ifCompany = false
                this.$refs.constructionFile.ifConstruction = true
            })
        },
        confirmConstruction(){
            let correct
            for(let i in this.$refs.safetyAction.tasksecurity){
                if(this.$refs.safetyAction.tasksecurity[i].checked === null || this.$refs.safetyAction.tasksecurity[i].checked === undefined || this.$refs.safetyAction.tasksecurity[i].checked === ''){
                    correct = 0
                    this.$message({
                        type:'warning',
                        message:'请完善安全措施'
                    })
                    break
                }else{
                    correct = 1
                }
            }
            if(correct === 1) {
                if (this.$refs.equipment.equipmentData.length === 0) {
                    this.$message({
                        type: 'warning',
                        message: '请完善设备'
                    })
                }else if(this.$refs.fireMan.taskWorkers.length === 0){
                    this.$message({
                        type: 'warning',
                        message: '请完善作业人'
                    })
                }
                // else if(this.$refs.constructionFile.fileListTwo.length === 0 || this.$refs.constructionFile.fileListThree.length === 0){
                //     this.$message({
                //         type: 'warning',
                //         message: '请上传作业人员健康和作业资质证书文件'
                //     })
                // }
                else {
                    this.constructionForm.taskEquipments = this.$refs.equipment.equipmentData
                    this.constructionForm.taskSecurities = this.$refs.safetyAction.tasksecurity
                    this.constructionForm.taskWorkers = this.$refs.fireMan.taskWorkers
                    submitConstruction(this.constructionForm).then(res => {
                        if (res.data.code === '200') {
                            this.$emit('getinfo')
                            this.taskCreateDialog = false
                            this.$notify({
                                type: 'success',
                                duration: 2000,
                                message: '施工单位确认成功',
                                title: '成功'
                            })
                        } else {
                            this.$message({
                                message: res.data.message,
                                type: 'warning'
                            })
                        }
                    }).catch(error => {
                        parseError({ error: error, vm: this })
                    })
                }
            }
        },
        refuse(){
            if(this.title === '动火部位审批'){
                this.basicForm.isAgree = 0
                this.supervisorAndAnalystRefuse = true
            }else if(this.title === '相关部门审批'){
                this.basicForm.isAgree = 0
                this.relevantRefuse = true
            }else if(this.title === '安全部门审批'){
                this.basicForm.isAgree = 0
                this.securityRefuse = true
            }
        },
        submitRefuseTaskByFireDepartment(){
            if(this.title === '动火部位审批'){
                partReview(this.basicForm).then(res=>{
                    if(res.data.code === '200'){
                        this.$emit('getinfo')
                        this.taskCreateDialog = false
                        this.supervisorAndAnalystRefuse = false
                        this.$notify({
                            title:'成功',
                            message:'审核驳回成功',
                            duration:2000,
                            type:'success'
                        })
                    }else{
                        this.$message({
                            type:'warning',
                            message:res.data.message
                        })
                    }
                }).catch(error =>{
                    parseError({error:error,vm:this})
                })
            }else if(this.title === '相关部门审批'){
                involveReview(this.basicForm).then(res=>{
                    if(res.data.code === '200'){
                        this.$emit('getinfo')
                        this.taskCreateDialog = false
                        this.relevantRefuse = false
                        this.$notify({
                            title:'成功',
                            message:'审核驳回成功',
                            duration:2000,
                            type:'success'
                        })
                    }else{
                        this.$message({
                            type:'warning',
                            message:res.data.message
                        })
                    }
                }).catch(error =>{
                    parseError({error:error,vm:this})
                })
            }else if(this.title === '安全部门审批'){
                securityReview(this.basicForm).then(res=>{
                    if(res.data.code === '200'){
                        this.$emit('getinfo')
                        this.taskCreateDialog = false
                        this.securityRefuse = false
                        this.$notify({
                            title:'成功',
                            message:'审核驳回成功',
                            duration:2000,
                            type:'success'
                        })
                    }else{
                        this.$message({
                            type:'warning',
                            message:res.data.message
                        })
                    }
                }).catch(error =>{
                    parseError({error:error,vm:this})
                })
            }

        },
        agree(){
            if(this.title === '动火部位审批'){
                this.basicForm.isAgree = 1
                this.supervisorAndAnalystAgree = true
            }else if(this.title === '相关部门审批'){
                this.basicForm.isAgree = 1
                involveReview(this.basicForm).then(res=>{
                    if(res.data.code === '200'){
                        this.$emit('getinfo')
                        this.taskCreateDialog = false
                        this.$notify({
                            title:'成功',
                            message:'审核通过成功',
                            duration:2000,
                            type:'success'
                        })
                    }else{
                        this.$message({
                            type:'warning',
                            message:res.data.message
                        })
                    }
                }).catch(error =>{
                    parseError({error:error,vm:this})
                })
            }else if(this.title === '安全部门审批'){
                this.basicForm.isAgree = 1
                securityReview(this.basicForm).then(res=>{
                    if(res.data.code === '200'){
                        this.$emit('getinfo')
                        this.taskCreateDialog = false
                        this.$notify({
                            title:'成功',
                            message:'审核通过成功',
                            duration:2000,
                            type:'success'
                        })
                    }else{
                        this.$message({
                            type:'warning',
                            message:res.data.message
                        })
                    }
                }).catch(error =>{
                    parseError({error:error,vm:this})
                })
            }
        },
        submitAgreeTaskByFireDepartment(){
            partReview(this.basicForm).then(res=>{
                if(res.data.code === '200'){
                    this.$emit('getinfo')
                    this.taskCreateDialog = false
                    this.supervisorAndAnalystAgree = false
                    this.$notify({
                        title:'成功',
                        message:'审核通过成功',
                        duration:2000,
                        type:'success'
                    })
                }else{
                    this.$message({
                        type:'warning',
                        message:res.data.message
                    })
                }
            }).catch(error =>{
                parseError({error:error,vm:this})
            })
        }
    }
}
</script>

<style scoped>

</style>
